==> windmill_api-1.450.1-py3-none-any.whl: windmill_api/models/run_flow_preview_json_body_value_modules_item_sleep_type_0.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0_type import (
    RunFlowPreviewJsonBodyValueModulesItemSleepType0Type,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="RunFlowPreviewJsonBodyValueModulesItemSleepType0")


@_attrs_define
class RunFlowPreviewJsonBodyValueModulesItemSleepType0:
    """
    Attributes:
        type (RunFlowPreviewJsonBodyValueModulesItemSleepType0Type):
        value (Union[Unset, Any]):
    """

    type: RunFlowPreviewJsonBodyValueModulesItemSleepType0Type
    value: Union[Unset, Any] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        value = self.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
            }
        )
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = RunFlowPreviewJsonBodyValueModulesItemSleepType0Type(d.pop("type"))

        value = d.pop("value", UNSET)

        run_flow_preview_json_body_value_modules_item_sleep_type_0 = cls(
            type=type,
            value=value,
        )

        run_flow_preview_json_body_value_modules_item_sleep_type_0.additional_properties = d
        return run_flow_preview_json_body_value_modules_item_sleep_type_0

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.513.0-py3-none-any.whl: windmill_api/models/run_flow_preview_json_body_value_modules_item_sleep_type_0.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.run_flow_preview_json_body_value_modules_item_sleep_type_0_type import (
    RunFlowPreviewJsonBodyValueModulesItemSleepType0Type,
)

T = TypeVar("T", bound="RunFlowPreviewJsonBodyValueModulesItemSleepType0")


@_attrs_define
class RunFlowPreviewJsonBodyValueModulesItemSleepType0:
    """
    Attributes:
        value (Any):
        type (RunFlowPreviewJsonBodyValueModulesItemSleepType0Type):
    """

    value: Any
    type: RunFlowPreviewJsonBodyValueModulesItemSleepType0Type
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        value = self.value
        type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "value": value,
                "type": type,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        value = d.pop("value")

        type = RunFlowPreviewJsonBodyValueModulesItemSleepType0Type(d.pop("type"))

        run_flow_preview_json_body_value_modules_item_sleep_type_0 = cls(
            value=value,
            type=type,
        )

        run_flow_preview_json_body_value_modules_item_sleep_type_0.additional_properties = d
        return run_flow_preview_json_body_value_modules_item_sleep_type_0

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
